/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Defines the possible orientations for the ActionSheet action buttons.
 * - `horizontal`: The actions are laid out in a horizontal row.
 * - `vertical`: The actions are stacked vertically.
 */
export type ActionSheetActionsOrientation = 'horizontal' | 'vertical';
/**
 * Defines the possible alignments for the ActionSheet action buttons.
 * - `start`: Aligns the actions to the start of the container.
 * - `center`: Centers the actions within the container.
 * - `end`: Aligns the actions to the end of the container.
 * - `stretched`: Stretches the actions to fill the available space.
 * - `justify`: Justifies the actions to distribute them evenly across the container.
 */
export type ActionSheetActionsAlignment = 'start' | 'center' | 'end' | 'stretched' | 'justify';
/**
 * Represents the layout configuration for the ActionSheet action buttons.
 */
export interface ActionSheetActionsLayout {
    /**
     * The orientation of the actions.
     * Defaults to `horizontal` if not specified.
     */
    orientation?: ActionSheetActionsOrientation;
    /**
     * The alignment of the actions within the container.
     * Defaults to `stretched` if not specified.
     */
    alignment?: ActionSheetActionsAlignment;
}
