/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ButtonFillMode, ButtonSize, ButtonThemeColor } from "@progress/kendo-angular-buttons";
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * The settings for the ActionSheet action buttons.
 */
export interface ActionSheetAction {
    /**
     * The unique identifier of the action button.
     */
    id?: string | number;
    /**
     * The text of the action button.
     */
    text?: string;
    /**
     * The font icon of the action button.
     */
    icon?: string;
    /**
     * The SVG icon of the action button.
     */
    svgIcon?: SVGIcon;
    /**
     * The title of the action button. The title shows as the default tooltip for the action button.
     */
    title?: string;
    /**
     * The size of the action button. The supported values are:
     * - `small`
     * - `medium`
     * - `large`
     * - `none`
     */
    size?: ButtonSize;
    /**
     * The fill mode of the action button. The supported values are:
     * - `flat`
     * - `outline`
     * - `solid`
     * - `link`
     * - `clear`
     * - `none`
     */
    fillMode?: ButtonFillMode;
    /**
     * The theme color of the action button. The possible values are:
     * - `base`: Applies coloring based on the base theme color.
     * - `primary`: Applies coloring based on the primary theme color.
     * - `secondary`: Applies coloring based on the secondary theme color.
     * - `tertiary`: Applies coloring based on the tertiary theme color.
     * - `info`: Applies coloring based on the info theme color.
     * - `success`: Applies coloring based on the success theme color.
     * - `warning`: Applies coloring based on the warning theme color.
     * - `error`: Applies coloring based on the error theme color.
     * - `dark`: Applies coloring based on the dark theme color.
     * - `light`: Applies coloring based on the light theme color.
     * - `inverse`: Applies coloring based on the inverse theme color.
     */
    themeColor?: ButtonThemeColor;
}
